#ifndef EFL_CANVAS_ANIMATION_PLAYER_IMPL_HH
#define EFL_CANVAS_ANIMATION_PLAYER_IMPL_HH

#include "efl_canvas_animation_player.eo.hh"

namespace efl { namespace canvas { 
inline ::efl::eolian::return_traits< ::efl::canvas::Animation>::type Animation_Player::animation_get() const
{
    ::Efl_Canvas_Animation* __return_value =  ::efl_animation_player_animation_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::canvas::Animation>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Animation_Player::animation_set( ::efl::eolian::in_traits< ::efl::canvas::Animation>::type animation) const
{
    ::efl_animation_player_animation_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Animation*,  ::efl::eolian::in_traits< ::efl::canvas::Animation>::type>(animation));
}
inline ::efl::eolian::return_traits<bool>::type Animation_Player::auto_del_get() const
{
   Eina_Bool __return_value =  ::efl_animation_player_auto_del_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Animation_Player::auto_del_set( ::efl::eolian::in_traits<bool>::type auto_del) const
{
    ::efl_animation_player_auto_del_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(auto_del));
}
inline ::efl::eolian::return_traits< ::efl::canvas::Object>::type Animation_Player::target_get() const
{
    ::Efl_Canvas_Object* __return_value =  ::efl_animation_player_target_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::canvas::Object>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Animation_Player::target_set( ::efl::eolian::in_traits< ::efl::canvas::Object>::type target) const
{
    ::efl_animation_player_target_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(target));
}
} } 
namespace eo_cxx {
namespace efl { namespace canvas { 
inline ::efl::eolian::return_traits< ::efl::canvas::Animation>::type Animation_Player::animation_get() const
{
    ::Efl_Canvas_Animation* __return_value =  ::efl_animation_player_animation_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::canvas::Animation>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Animation_Player::animation_set( ::efl::eolian::in_traits< ::efl::canvas::Animation>::type animation) const
{
    ::efl_animation_player_animation_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Animation*,  ::efl::eolian::in_traits< ::efl::canvas::Animation>::type>(animation));
}
inline ::efl::eolian::return_traits<bool>::type Animation_Player::auto_del_get() const
{
   Eina_Bool __return_value =  ::efl_animation_player_auto_del_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Animation_Player::auto_del_set( ::efl::eolian::in_traits<bool>::type auto_del) const
{
    ::efl_animation_player_auto_del_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(auto_del));
}
inline ::efl::eolian::return_traits< ::efl::canvas::Object>::type Animation_Player::target_get() const
{
    ::Efl_Canvas_Object* __return_value =  ::efl_animation_player_target_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::canvas::Object>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Animation_Player::target_set( ::efl::eolian::in_traits< ::efl::canvas::Object>::type target) const
{
    ::efl_animation_player_target_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(target));
}
inline efl::canvas::Animation_Player::operator ::efl::canvas::Animation_Player() const { return *static_cast< ::efl::canvas::Animation_Player const*>(static_cast<void const*>(this)); }
inline efl::canvas::Animation_Player::operator ::efl::canvas::Animation_Player&() { return *static_cast< ::efl::canvas::Animation_Player*>(static_cast<void*>(this)); }
inline efl::canvas::Animation_Player::operator ::efl::canvas::Animation_Player const&() const { return *static_cast< ::efl::canvas::Animation_Player const*>(static_cast<void const*>(this)); }
} } }
#endif
